.. -*- rst -*-

Authors
-------
This software was written and packaged by Lev Givon [1]_. It was inspired in
part by cuda-mps-helper, by Alexander Monakov [2]_.


.. [1] http://www.columbia.edu/~lev/
.. [2] https://github.com/amonakov/cuda-mps-helper/
